function a=analitika(S,p,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Funkcija za racunanje cogging momenta sinhrone masine sa stalnim 
%   magnetima. Moguce je proizvoljno menjati broj pari polova p i broj 
%   zlebova S. Simulira se cogging momenat tako sto se menja osobina
%   granicnog uslova koji opisuje zazor.
%
%   Filip Cvejic
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%ulazni parametri
u0=4e-7*pi;
R=24.8e-3;
L=0.07;
beta=0.2045;
betaA=0.15;
Bm=0.96;

h=20;
N=1000;

NZS=lcm(2*p,S);
j0=NZS/(2*p);
i0=NZS/S;
Mem=0;

%mehanicki ugao
tetaM=linspace(0,(2*2*pi)/(2*p*j0),N);

%proracun koef. Furijeovog reda za velicine A i delta za prvih h harmonika
for pom=1:1:h
    i=i0*pom;
    j=j0*pom;
    
    ai=-R/(2*S*i^2)*(1+cos(2*pi*i*beta)-sin(2*pi*i*beta)/(pi*i*beta));
    bi=R/(2*S*i^2)*((1-cos(2*pi*i*beta))/(pi*i*beta)-sin(2*pi*i*beta));
    fi_deltai=atan2(bi,ai);
    deltai=abs(ai+1j*bi);
    
    Aj=-2*Bm^2/(pi*j^1.65)*sin(betaA*pi*j);
    fi_Aj=0;
    
    fi_ij=fi_deltai-fi_Aj;
    Mem_add=-pi*R*L/u0*deltai*Aj*p*j*sin(2*p*j*tetaM-fi_ij);
    Mem=Mem+Mem_add;

end

%skiciramo cogg. torque ili vracamo amplitudu
if(nargin==3)
    Mem = circshift(Mem,453);
    figure(varargin{1});
    plot(57.33*tetaM,Mem);
else
    a=max(Mem);
end    
end