function torquef(S,p,fig)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Funkcija za racunanje cogging momenta sinhrone masine sa stalnim 
%   magnetima u FEMM42. Moguce je proizvoljno menjati broj pari polova p
%   i broj zlebova S. Simulira se cogging momenat tako sto se menja osobina
%   granicnog uslova koji opisuje zazor. Parametar fig je oznaka figure na
%   kojoj treba da se iscrta talasni oblik.
%
%   Filip Cvejic
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% nacrtaj motor
motorf(S,p);

% sacuvaj kao privremeni file za svaki slucaj
mi_saveas('tmp1.fem');
%%
n = 100;        % broj koraka simulacije
torque = zeros(1,n);
aend = 360/S;      % maksimalni ugao rotacije
dtheta = aend/n;
theta = 0;

% prikaz progresa
wb = waitbar(0,sprintf('Working... %i%% (%i/%i)',0,0,n),...
    'Name',sprintf('Progress (%ideg)',aend));

for i=1:n
    mi_analyze(1);              % analiziraj, sakrij prozor sa progresom
    mi_loadsolution;            % ucitaj reenje analize
    torque(i) = mo_gapintegral('gapslide',0);
                                % izracunaj momenat
    theta = theta + dtheta;     % rotiraj za korak
    mi_modifyboundprop('gapslide',10,theta);
    waitbar(i/n,wb,sprintf('Working... %i%% (%i/%i)',fix(100*i/n),i,n));
                                % osvei progres
end
close(wb); % zatvori pozor sa progresom kad zavri
%%
k=2;
t1=torque;
for i=1:k-1
    t1=[t1,torque]; %#ok<AGROW>
end

% prikaz talasnog oblika momenta
figure(fig);
hold on;
plot(linspace(0,k*aend,k*n),t1);
xlim([0,k*aend]);

% vrati rotor u pocetni polozaj
mi_modifyboundprop('gapslide',10,0);

%%
mo_close;




































